# Models for predicting brightness ratings as a function of formant frequencies in real and synthetic vowels

setwd('/home/allgoodguys/Documents/Studying/Lund_PhD/epistles/011_soundCol_linguistic/exp1_ipa_brightness')
library(brms)
source('/home/allgoodguys/Documents/Soft_comp/R/ggplot_multiple.R')  # from http://www.cookbook-r.com/Graphs/Multiple_graphs_on_one_page_(ggplot2)/

df1 = read.csv('data/ipa_audio_long_vowels.csv')
df2 = read.csv('data/ipa_audio_long_soundgen.csv')

summary(lm(br ~ F1 + F2 + F3 + F4, df1))

nf = function(x) {
  semit = soundgen::HzToSemitones(x)
  semit = semit - mean(semit)
  semit
}

df1$br01 = df1$br / 102 + .01  # range(df1$br01)
df1$F1_log = nf(df1$F1)
df1$F2_log = nf(df1$F2)
df1$F3_log = nf(df1$F3)
df1$F4_log = nf(df1$F4)

# summary(lm(br ~ F1_log + F2_log + F3_log + F4_log, df1))
# pairs(df1[, c('br', 'F1_log', 'F2_log', 'F3_log', 'F4_log')])

mod_v = brm(br01 ~ F1_log + F2_log + F3_log, data = df1, family = 'beta', cores = 4, chains = 4, warmup = 500, iter = 4000)
# summary(mod_v)
# brms::pp_check(mod_v)
# brms::marginal_effects(mod_v)
# plot(mod_v)

# effect of F1-3 on br
f1 = fitted(mod_v, 
            newdata = data.frame(
              F1_log = c(min(df1$F1_log), max(df1$F1_log)),
              F2_log = 0, F3_log = 0, F4_log = 0
            ), 
            summary = FALSE)
soundgen:::reportCI(quantile((f1[, 2] - f1[, 1] - .01) * 102, probs = c(.5, 0.025, .975)), digits = 1)

f2 = fitted(mod_v, 
            newdata = data.frame(
              F1_log = 0,
              F2_log = c(min(df1$F2_log), max(df1$F2_log)),
              F3_log = 0, F4_log = 0
            ), 
            summary = FALSE)
soundgen:::reportCI(quantile((f2[, 2] - f2[, 1] - .01) * 102, probs = c(.5, 0.025, .975)), digits = 1)

f3 = fitted(mod_v, 
            newdata = data.frame(
              F1_log = 0, F2_log = 0,
              F3_log = c(min(df1$F3_log), max(df1$F3_log)),
              F4_log = 0
            ), 
            summary = FALSE)
soundgen:::reportCI(quantile((f3[, 2] - f3[, 1] - .01) * 102, probs = c(.5, 0.025, .975)), digits = 1)


newdata1 = data.frame(
  formant = 'F1',
  F1_log = seq(min(df1$F1_log), max(df1$F1_log), length.out = 100),
  F2_log = 0, F3_log = 0
)
newdata2 = data.frame(
  formant = 'F2',
  F1_log = 0,
  F2_log = seq(min(df1$F2_log), max(df1$F2_log), length.out = 100), 
  F3_log = 0
)
newdata3 = data.frame(
  formant = 'F3',
  F1_log = 0, F2_log = 0, 
  F3_log = seq(min(df1$F3_log), max(df1$F3_log), length.out = 100)
)
newdata = rbind(newdata1, newdata2, newdata3)

f1 = fitted(mod_v, newdata, re_formula = NA, robust = TRUE)
f1 = (f1 - .01) * 102
colnames(f1) = c('fit', 'se', 'lwr', 'upr')
df_plot1 = cbind(newdata, f1)

for (i in 1:nrow(df_plot1)) {
  if (df_plot1$formant[i] == 'F1') {
    df_plot1$value[i] = df_plot1$F1_log[i]
  } else if (df_plot1$formant[i] == 'F2') {
    df_plot1$value[i] = df_plot1$F2_log[i]
  } else {
    df_plot1$value[i] = df_plot1$F3_log[i]
  }
}

p3 = ggplot(df_plot1, aes(x = value, y = fit, ymin = lwr, ymax = upr, group = formant, linetype = formant, fill = formant)) +
  geom_ribbon(alpha = .2, color = 'white') +
  geom_line() +
  ylim(c(0, 100)) +
  xlab('Relative formant frequency, semitones') +
  ylab('Relative brightness rating, %') +
  ggtitle('C. Vowels: predicted') +
  theme_bw() +
  theme(panel.grid = element_blank(), 
        legend.title = element_blank())
# ggsave('analysis/pix/br~F123.png', width = 10, height = 10, units = 'cm', dpi = 300)


## SYNTHETIC VOWELS
df2$br01 = df2$br / 102 + .01  # range(df2$br01)
df2$F1_log = nf(df2$F1)
df2$F2_log = nf(df2$F2)
df2$F3_log = nf(df2$F3)
df2$F4_log = nf(df2$F4)

mod_sg = brm(br01 ~ F1_log + F2_log + F3_log, data = df2, family = 'beta', cores = 4, chains = 4, warmup = 500, iter = 4000)
# summary(mod_sg)
# brms::pp_check(mod_sg)
# brms::marginal_effects(mod_sg)
# plot(mod_sg)

# effect of F1-3 on br
f1 = fitted(mod_sg, 
            newdata = data.frame(
              F1_log = c(min(df2$F1_log), max(df2$F1_log)),
              F2_log = 0, F3_log = 0, F4_log = 0
            ), 
            summary = FALSE)
soundgen:::reportCI(quantile((f1[, 2] - f1[, 1] - .01) * 102, probs = c(.5, 0.025, .975)), digits = 1)

f2 = fitted(mod_sg, 
            newdata = data.frame(
              F1_log = 0,
              F2_log = c(min(df2$F2_log), max(df2$F2_log)),
              F3_log = 0, F4_log = 0
            ), 
            summary = FALSE)
soundgen:::reportCI(quantile((f2[, 2] - f2[, 1] - .01) * 102, probs = c(.5, 0.025, .975)), digits = 1)

f3 = fitted(mod_sg, 
            newdata = data.frame(
              F1_log = 0, F2_log = 0,
              F3_log = c(min(df2$F3_log), max(df2$F3_log)),
              F4_log = 0
            ), 
            summary = FALSE)
soundgen:::reportCI(quantile((f3[, 2] - f3[, 1] - .01) * 102, probs = c(.5, 0.025, .975)), digits = 1)

f2 = fitted(mod_sg, newdata, re_formula = NA, robust = TRUE)
f2 = (f2 - .01) * 102
colnames(f2) = c('fit', 'se', 'lwr', 'upr')
df_plot2 = cbind(newdata, f2)

for (i in 1:nrow(df_plot2)) {
  if (df_plot2$formant[i] == 'F1') {
    df_plot2$value[i] = df_plot2$F1_log[i]
  } else if (df_plot2$formant[i] == 'F2') {
    df_plot2$value[i] = df_plot2$F2_log[i]
  } else {
    df_plot2$value[i] = df_plot2$F3_log[i]
  }
}

p4 = ggplot(df_plot2, aes(x = value, y = fit, ymin = lwr, ymax = upr, group = formant, linetype = formant, fill = formant)) +
  geom_ribbon(alpha = .2, color = 'white') +
  geom_line() +
  ylim(c(0, 100)) +
  xlab('Relative formant frequency, semitones') +
  ylab('Relative brightness rating, %') +
  ggtitle('D. Synthetic vowels: predicted') +
  theme_bw() +
  theme(panel.grid = element_blank(), 
        legend.title = element_blank())


## OBSERVED
ipa = read.csv('/home/allgoodguys/Documents/Studying/Lund_PhD/epistles/011_soundCol_linguistic/exp1_ipa_brightness/data/ipa_audio.csv')
ipa_v = droplevels(ipa[!is.na(ipa$F1), ])

base_breaks = function(n = 10){
  function(x) {
    axisTicks(log10(range(x, na.rm = TRUE)), log = TRUE, n = n)
  }
}

ipa_v$logF1 = log2(ipa_v$F1)
ipa_v$logF2 = log2(ipa_v$F2)

library(scales)
p1 = ggplot(ipa_v, aes(y = logF1, x = logF2, color = br, label = ipa)) +
  geom_text(size = 6) +
  scale_x_reverse(breaks = log2(pretty(range(ipa_v$F2), n = 5)), labels = pretty(range(ipa_v$F2), n = 5) / 1000) +
  scale_y_reverse(breaks = log2(pretty(range(ipa_v$F1), n = 5)), labels = pretty(range(ipa_v$F1), n = 5) / 1000) +
  scale_color_gradient(name = 'Brightness', low = 'blue', high = 'yellow') + # low = 'gray10', high = 'gray80'
  ylab('F1, kHz') + xlab('F2, kHz') +
  ggtitle('A. Vowels: observed') +
  theme_bw() +
  theme(panel.grid = element_blank())
# ggsave('pix/vowels_f1f2~br.png', width = 12, height = 10, units = 'cm', dpi = 300, scale = 1.1)

p2 = ggplot(ipa_v, aes(y = logF1, x = logF2, color = brs, label = ipa)) +
  geom_text(size = 6) +
  scale_x_reverse(breaks = log2(pretty(range(ipa_v$F2), n = 5)), labels = pretty(range(ipa_v$F2), n = 5) / 1000) +
  scale_y_reverse(breaks = log2(pretty(range(ipa_v$F1), n = 5)), labels = pretty(range(ipa_v$F1), n = 5) / 1000) +
  scale_color_gradient(name = 'Brightness', low = 'blue', high = 'yellow') + # low = 'gray10', high = 'gray80'
  ylab('F1, kHz') + xlab('F2, kHz') +
  ggtitle('B. Synthetic vowels: observed') +
  theme_bw() +
  theme(panel.grid = element_blank())
# ggsave('pix/vowels_soundgen_f1f2~br.png', width = 12, height = 10, units = 'cm', dpi = 300, scale = 1.1)

multiplot(p1, p3, p2, p4, cols = 2)
# ggsave(multiplot(p1, p3, p2, p4, cols = 2), filename = 'pix/br~F123.png', width = 20, height = 15, units = 'cm', dpi = 300)