# Models for predicting brightness ratings as a function of specCentroid

setwd('/home/allgoodguys/Documents/Studying/Lund_PhD/epistles/011_soundCol_linguistic/exp1_ipa_brightness')
library(brms)
source('/home/allgoodguys/Documents/Soft_comp/R/ggplot_multiple.R')  # from http://www.cookbook-r.com/Graphs/Multiple_graphs_on_one_page_(ggplot2)/

df1 = read.csv('data/ipa_audio_long_vowels.csv')
df2 = read.csv('data/ipa_audio_long_soundgen.csv')
df3 = read.csv('data/ipa_audio_long_cons.csv')

ipa = read.csv('/home/allgoodguys/Documents/Studying/Lund_PhD/epistles/011_soundCol_linguistic/exp1_ipa_brightness/data/ipa_audio.csv')
ipas = read.csv('/home/allgoodguys/Documents/Studying/Lund_PhD/epistles/011_soundCol_linguistic/exp1_ipa_brightness/data/ipa_audio_synthetic.csv')
ipa_v = droplevels(ipa[!is.na(ipa$F1), ])

base_breaks = function(n = 10){
  function(x) {
    axisTicks(log10(range(x, na.rm = TRUE)), log = TRUE, n = n)
  }
}

## REAL VOWELS
df1$br01 = df1$br / 102 + .01  # range(df_long$br01)
df1$logSC = log(df1$specCentroid_median)
mod_brSC = brm(br01 ~ logSC, data = df1, family = 'beta', cores = 4, chains = 4, warmup = 500, iter = 4000)
# mod_brSC2 = brm(br01 ~ logSC + (1|id), data = df1, family = 'beta', cores = 4, chains = 4, warmup = 500, iter = 4000)
# mod_brSC3 = brm(br01 ~ logSC + (logSC|id), data = df1, family = 'beta', cores = 4, chains = 4, warmup = 500, iter = 4000, control = list(adapt_delta = .99))  # 4 min
# WAIC(mod_brSC, mod_brSC2, mod_brSC3)  # just the simple mod_brSC works best
summary(mod_brSC)

newdata = data.frame(logSC = seq(min(df1$logSC), max(df1$logSC), length.out = 100))
f = fitted(mod_brSC, newdata, robust = TRUE)
colnames(f) = c('fit', 'se', 'lwr', 'upr')
f = (f - .01) * 102
df_plot_brSC = cbind(newdata, f)
df_plot_brSC$sc = exp(df_plot_brSC$logSC)

p1 = ggplot(df_plot_brSC, aes(x = sc, y = fit, ymin = lwr, ymax = upr)) +
  geom_ribbon(alpha = .25) +
  geom_line() +
  geom_text(data = ipa_v, aes(x = specCentroid_median, y = br, label = ipa), inherit.aes = FALSE) +
  scale_x_continuous(trans = 'log2', breaks = base_breaks(5)) +
  xlab('') + ylab('Perceived brightness, %') +
  ggtitle('A. Vowels') +
  theme_bw() +
  theme(panel.grid = element_blank())


## SYNTHETIC VOWELS
df2$br01 = df2$br / 102 + .01  # range(df_longS$br01)
df2$logSC = log(df2$specCentroid_median)
mod_brSC_soundgen = brm(br01 ~ logSC, data = df2, family = 'beta', cores = 4, chains = 4, warmup = 500, iter = 4000)
summary(mod_brSC_soundgen)

newdata = data.frame(logSC = seq(min(df2$logSC), max(df2$logSC), length.out = 100))
f = fitted(mod_brSC_soundgen, newdata, robust = TRUE)
colnames(f) = c('fit', 'se', 'lwr', 'upr')
f = (f - .01) * 102
df_plot_brSC_soundgen = cbind(newdata, f)
df_plot_brSC_soundgen$sc = exp(df_plot_brSC_soundgen$logSC)

p2 = ggplot(df_plot_brSC_soundgen, aes(x = sc, y = fit, ymin = lwr, ymax = upr)) +
  geom_ribbon(alpha = .25) +
  geom_line() +
  geom_text(data = ipas, aes(x = specCentroid_median, y = br, label = ipa), inherit.aes = FALSE) +
  scale_x_continuous(trans = 'log2', breaks = base_breaks(5)) +
  xlab('Spectral centroid, Hz') + ylab('') +
  ggtitle('B. Synthetic vowels') +
  theme_bw() +
  theme(panel.grid = element_blank())


## CONSONANTS
ipa_c = droplevels(ipa[is.na(ipa$F1) & !is.na(ipa$br), ])

plot(ipa_c$specCentroid, ipa_c$br, type = 'n')
text(ipa_c$specCentroid, ipa_c$br, labels = ipa_c$ipa)

plot(log(ipa_c$specCentroid), ipa_c$br, type = 'n')
text(log(ipa_c$specCentroid), ipa_c$br, labels = ipa_c$ipa)

df3$br01 = df3$br / 102 + .01  # range(df_long$br01)
df3$logSC = log(df3$specCentroid_median)
mod_br_cons = brm(br01 ~ logSC, data = df3, family = 'beta', cores = 4, chains = 4, warmup = 500, iter = 4000)
summary(mod_br_cons)

newdata = data.frame(logSC = seq(min(df3$logSC), max(df3$logSC), length.out = 100))
f = fitted(mod_br_cons, newdata, robust = TRUE)
colnames(f) = c('fit', 'se', 'lwr', 'upr')
f = (f - .01) * 102
df_plot_br_cons = cbind(newdata, f)
df_plot_br_cons$sc = exp(df_plot_br_cons$logSC)

p3 = ggplot(df_plot_br_cons, aes(x = sc, y = fit, ymin = lwr, ymax = upr)) +
  geom_ribbon(alpha = .25) +
  geom_line() +
  geom_text(data = ipa_c, aes(x = specCentroid_median, y = br, label = ipa), inherit.aes = FALSE) +
  scale_x_continuous(trans = 'log2', breaks = base_breaks(5)) +
  xlab('') + ylab('') +
  ggtitle('C. Consonants') +
  theme_bw() +
  theme(panel.grid = element_blank())


multiplot(p1, p2, p3, cols = 3)
# ggsave(multiplot(p1, p2, p3, cols = 3), filename = 'pix/br~SC.png', width = 20, height = 8, units = 'cm', dpi = 300)