# Correlations between different acoustic predictors and brightness ratings

setwd('/home/allgoodguys/Documents/Studying/Lund_PhD/epistles/011_soundCol_linguistic/exp1_ipa_brightness')
source('/home/allgoodguys/Documents/Soft_comp/R/ggplot_multiple.R')  # from http://www.cookbook-r.com/Graphs/Multiple_graphs_on_one_page_(ggplot2)/


ipa = read.csv('/home/allgoodguys/Documents/Studying/Lund_PhD/epistles/011_soundCol_linguistic/exp1_ipa_brightness/data/ipa_audio.csv')
# colnames(ipa)

myvars = c('specCentroid', 'specCentroid_median', 'specMed', 'medianFreq_median', 'melCentroid', 'melMed', 'peakFreq', 'peakFreq_median', 'F1', 'F2', 'F3', 'F4', 'F5', 'F6')  # to be log-transformed
n = length(myvars) + 4
out = data.frame(v = c('sonority', 'ampl_median', 'loudness_median', myvars), cor_vowel = NA, cor_soundgen = NA, cor_cons = NA)

ipa_log = ipa
ipa_log[, myvars] = log(ipa_log[, myvars])

ipas = read.csv('/home/allgoodguys/Documents/Studying/Lund_PhD/epistles/011_soundCol_linguistic/exp1_ipa_brightness/data/ipa_audio_synthetic.csv')
ipas_log = ipas
ipas_log[, myvars] = log(ipas_log[, myvars])


# cor(ipa_log[, c('sonority', 'ampl_median', 'loudness_median', 'specCentroid_median', 'medianFreq_median', 'peakFreq_median', 'specCentroid', 'specCentroid_dB', 'specMed', 'specMed_dB', 'peakFreq', 'melCentroid', 'melCentroid_dB', 'melMed', 'melMed_dB')])[, 1]

out$cor_vowel = cor(ipa_log[!is.na(ipa_log$F1), c('br', 'sonority', 'ampl_median', 'loudness_median', myvars)])[2:n, 1]
out$cor_soundgen = cor(ipas_log[, c('br', 'sonority', 'ampl_median', 'loudness_median', myvars)])[2:n, 1]
out$cor_cons = cor(ipa_log[is.na(ipa_log$F1), c('br', 'sonority', 'ampl_median', 'loudness_median', myvars)], use = 'pairwise.complete.obs')[2:n, 1]

out$meancor = apply(out[, 2:4], 1, mean, na.rm = TRUE)
out = out[order(out$meancor, decreasing = TRUE), ]

out[, 2:ncol(out)] = round(out[, 2:ncol(out)], 2)
out
# write.csv(out, '~/Downloads/temp.csv')


## ICC
df1 = read.csv('ipa_audio_long_vowels.csv')
df2 = read.csv('ipa_audio_long_soundgen.csv')
df3 = read.csv('ipa_audio_long_cons.csv')

library(ICC)
ICCest(df1, x = ipa, y = br)$ICC  # .55
ICCest(df2, x = ipa, y = br)$ICC  # .66
ICCest(df3, x = ipa, y = br)$ICC  # .41


# # Using individual ratings insteady of medians
# for (i in 1:3) {
#   df = get(paste0('df', i))
#   # plot(df$specCentroid, df$br)
#   
#   # (optional) log-transform: 
#   df_log = df
#   df_log = as.data.frame(apply(df_log, 2, as.numeric))  # otherwise F1-F6 become logical in cons
#   df_log[, myvars] = log(df_log[, myvars])
#   # plot(df_log$specCentroid, df_log$br)
#   
#   mycor = cor(df_log[, c('br', myvars)])[, 1]  
#   out[, i + 1] = mycor[2:length(mycor)]
# }


if (FALSE) {
  ipa_v = ipa_log[!is.na(ipa_log$F1), ]
  
  cor(ipa_v[, c('F1', 'sonority', 'br')])
  
  plot(ipa_v$sonority, ipa_v$br, type = 'n')
  text(ipa_v$sonority, ipa_v$br, labels = ipa_v$unicode)
  
  plot(ipa_v$sonority, ipa_v$brs, type = 'n')
  text(ipa_v$sonority, ipa_v$brs, labels = ipa_v$unicode)
  
  plot(ipa_v$sonority, ipa_v$F1, type = 'n')
  text(ipa_v$sonority, ipa_v$F1, labels = ipa_v$unicode)
  
  plot(ipa_log[!is.na(ipa_log$F1), c('F5', 'br')])
  cor(ipa_log[!is.na(ipa_log$F1), c('F5', 'br')])
  
  plot(ipas_log[!is.na(ipas_log$F1), c('F5', 'br')])
  cor(ipas_log[!is.na(ipas_log$F1), c('F5', 'br')])
  
  plot(ipa_log$br[1:21], ipas_log$br)
}



## How are RMS amplitude and loudness related to sonority?
ipa$son01 = ((ipa$sonority - 1) / 15.1) + .005
range(ipa$son01)
ipa$vowel = ifelse(is.na(ipa$F1), 'Consonants', 'Vowels')
ipa$log_f1 = log(ipa$F1)
ipa$log_f2 = log(ipa$F2)
cor(ipa[, c('sonority', 'ampl_median', 'loudness_median', 'log_f1', 'log_f2')], use = 'complete.obs')[, 1]

# RMS amplitude
mod_son_ampl = brm(son01 ~ ampl_median * vowel, data = ipa, family = 'beta', chains = 2, cores = 2, warmup = 500, iter = 6000)
summary(mod_son_ampl)
# brms::pp_check(mod_son_ampl)

newdata_ampl = expand.grid(
  vowel = unique(ipa$vowel),
  ampl_median = seq(min(ipa$ampl_median), max(ipa$ampl_median), length.out = 100)
)
fit_ampl = fitted(mod_son_ampl, newdata = newdata_ampl, robust = TRUE)[, c(1, 3, 4)]
colnames(fit_ampl) = c('fit', 'lwr', 'upr')
df_plot_ampl = cbind(newdata_ampl, fit_ampl)
df_plot_ampl[, c('fit', 'lwr', 'upr')] = (df_plot_ampl[, c('fit', 'lwr', 'upr')] - .005) * 15.1 + 1

# limit to observed range of values
range_vowel = range(ipa$ampl_median[ipa$vowel == 'Vowels'])
range_cons = range(ipa$ampl_median[ipa$vowel == 'Consonants'])
idx_ampl = rep(TRUE, nrow(df_plot_ampl))
for (i in 1:nrow(df_plot_ampl)) {
  if (df_plot_ampl$vowel[i] == 'Vowels') {
    idx_ampl[i] = df_plot_ampl$ampl_median[i] >= range_vowel[1] &
      df_plot_ampl$ampl_median[i] <= range_vowel[2]
  } else {
    idx_ampl[i] = df_plot_ampl$ampl_median[i] >= range_cons[1] &
      df_plot_ampl$ampl_median[i] <= range_cons[2]
  }
}
df_plot_ampl = df_plot_ampl[idx_ampl, ]

p_ampl = ggplot(df_plot_ampl, aes(x = ampl_median, y = fit, ymin = lwr, ymax = upr, color = vowel, linetype = vowel, fill = vowel)) +
  geom_line() +
  geom_ribbon(linetype = 0, alpha = .2) +
  geom_text(data = ipa, aes(x = ampl_median, y = sonority, label = ipa, color = vowel), inherit.aes = FALSE) +
  xlab('RMS amplitude') +
  ylab('Sonority') +
  ggtitle('A. RMS amplitude') +
  theme_bw() +
  theme(panel.grid = element_blank(),
        legend.title = element_blank())
# vowels: no effect; consonants: good positive predictor


# Loudness
mod_son_loudness = brm(son01 ~ loudness_median * vowel, data = ipa, family = 'beta', chains = 2, cores = 2, warmup = 500, iter = 6000)
summary(mod_son_loudness)
# brms::pp_check(mod_son_loudness)

newdata_loudness = expand.grid(
  vowel = unique(ipa$vowel),
  loudness_median = seq(min(ipa$loudness_median), max(ipa$loudness_median), length.out = 100)
)
fit_loudness = fitted(mod_son_loudness, newdata = newdata_loudness, robust = TRUE)[, c(1, 3, 4)]
colnames(fit_loudness) = c('fit', 'lwr', 'upr')
df_plot_loudness = cbind(newdata_loudness, fit_loudness)
df_plot_loudness[, c('fit', 'lwr', 'upr')] = (df_plot_loudness[, c('fit', 'lwr', 'upr')] - .005) * 15.1 + 1

# limit to observed range of values
range_vowel = range(ipa$loudness_median[ipa$vowel == 'Vowels'])
range_cons = range(ipa$loudness_median[ipa$vowel == 'Consonants'])
idx_loud = rep(TRUE, nrow(df_plot_loudness))
for (i in 1:nrow(df_plot_ampl)) {
  if (df_plot_loudness$vowel[i] == 'Vowels') {
    idx_loud[i] = df_plot_loudness$loudness_median[i] >= range_vowel[1] &
      df_plot_loudness$loudness_median[i] <= range_vowel[2]
  } else {
    idx_loud[i] = df_plot_loudness$loudness_median[i] >= range_cons[1] &
      df_plot_loudness$loudness_median[i] <= range_cons[2]
  }
}
df_plot_loudness = df_plot_loudness[idx_loud, ]

p_loud = ggplot(df_plot_loudness, aes(x = loudness_median, y = fit, ymin = lwr, ymax = upr, color = vowel, linetype = vowel, fill = vowel)) +
  geom_line() +
  geom_ribbon(linetype = 0, alpha = .2) +
  geom_text(data = ipa, aes(x = loudness_median, y = sonority, label = ipa, color = vowel), inherit.aes = FALSE) +
  xlab('Loudness (sone)') +
  ylab('Sonority') +
  ggtitle('B. Loudness') +
  theme_bw() +
  theme(panel.grid = element_blank(),
        legend.title = element_blank())
# good positive predictor for both vowels and consonants


# F1
ipa_vowels = ipa[!is.na(ipa$F1), ]
mod_son_F1 = brm(son01 ~ log_f1, data = ipa_vowels, family = 'beta', chains = 2, cores = 2, warmup = 500, iter = 6000)
summary(mod_son_F1)
# brms::pp_check(mod_son_F1)

newdata_F1 = data.frame(log_f1 = seq(min(ipa_vowels$log_f1), max(ipa_vowels$log_f1), length.out = 100))
fit_F1 = fitted(mod_son_F1, newdata = newdata_F1, robust = TRUE)[, c(1, 3, 4)]
colnames(fit_F1) = c('fit', 'lwr', 'upr')
df_plot_F1 = cbind(newdata_F1, fit_F1)
df_plot_F1[, c('fit', 'lwr', 'upr')] = (df_plot_F1[, c('fit', 'lwr', 'upr')] - .005) * 15.1 + 1
df_plot_F1$F1 = exp(df_plot_F1$log_f1)

p_F1 = ggplot(df_plot_F1, aes(x = F1, y = fit, ymin = lwr, ymax = upr)) +
  geom_line() +
  geom_ribbon(linetype = 0, alpha = .2) +
  geom_text(data = ipa_vowels, aes(x = F1, y = sonority, label = ipa), inherit.aes = FALSE) +
  xlab('F1, Hz') +
  ylab('Sonority') +
  ggtitle('C. F1') +
  theme_bw() +
  theme(panel.grid = element_blank(),
        legend.title = element_blank())
# moderate effect of F1

# F2
mod_son_F2 = brm(son01 ~ log_f2, data = ipa_vowels, family = 'beta', chains = 2, cores = 2, warmup = 500, iter = 6000)
summary(mod_son_F2)
# brms::pp_check(mod_son_F2)

newdata_F2 = data.frame(log_f2 = seq(min(ipa_vowels$log_f2), max(ipa_vowels$log_f2), length.out = 100))
fit_F2 = fitted(mod_son_F2, newdata = newdata_F2, robust = TRUE)[, c(1, 3, 4)]
colnames(fit_F2) = c('fit', 'lwr', 'upr')
df_plot_F2 = cbind(newdata_F2, fit_F2)
df_plot_F2[, c('fit', 'lwr', 'upr')] = (df_plot_F2[, c('fit', 'lwr', 'upr')] - .005) * 15.1 + 1
df_plot_F2$F2 = exp(df_plot_F2$log_f2)

p_F2 = ggplot(df_plot_F2, aes(x = F2, y = fit, ymin = lwr, ymax = upr)) +
  geom_line() +
  geom_ribbon(linetype = 0, alpha = .2) +
  geom_text(data = ipa_vowels, aes(x = F2, y = sonority, label = ipa), inherit.aes = FALSE) +
  xlab('F2, Hz') +
  ylab('Sonority') +
  ggtitle('D. F2') +
  theme_bw() +
  theme(panel.grid = element_blank(),
        legend.title = element_blank())
# no effect of F2

multiplot(p_ampl, p_F1, p_loud, p_F2, cols = 2)
ggsave(multiplot(p_ampl, p_loud, cols = 2),
       filename = 'pix/sonority_ampl_loudness.png', width = 20, height = 8, units = 'cm', dpi = 300)



## sonority ~ br
mod_son_br = brm(son01 ~ br, data = ipa_vowels, family = 'beta', chains = 2, cores = 2, warmup = 500, iter = 6000)
summary(mod_son_br)

newdata_br = data.frame(br = seq(min(ipa_vowels$br), max(ipa_vowels$br), length.out = 100))
fit_br = fitted(mod_son_br, newdata = newdata_br, robust = TRUE)[, c(1, 3, 4)]
colnames(fit_br) = c('fit', 'lwr', 'upr')
df_plot_br = cbind(newdata_br, fit_br)
df_plot_br[, c('fit', 'lwr', 'upr')] = (df_plot_br[, c('fit', 'lwr', 'upr')] - .005) * 15.1 + 1

p_br = ggplot(df_plot_br, aes(x = br, y = fit, ymin = lwr, ymax = upr)) +
  geom_line() +
  geom_ribbon(linetype = 0, alpha = .2) +
  geom_text(data = ipa_vowels, aes(x = br, y = sonority, label = ipa), inherit.aes = FALSE) +
  xlab('Brightness rating, %') +
  ylab('Sonority') +
  theme_bw() +
  theme(panel.grid = element_blank(),
        legend.title = element_blank())
ggsave(filename = 'pix/sonority~br.png', width = 8, height = 8, units = 'cm', dpi = 300)
