# Consonants: luminance and saturation of color as predictors of acoustic characteristics of consonants

setwd('/home/allgoodguys/Documents/Studying/Lund_PhD/epistles/011_soundCol_linguistic/exp2_text')

library(ggplot2)
library(lme4)
library(reshape2)
library(brms)
source('/home/allgoodguys/Documents/Soft_comp/R/ggplot_multiple.R')  # from http://www.cookbook-r.com/Graphs/Multiple_graphs_on_one_page_(ggplot2)/

### LUMINANCE
# load data
ipa = read.csv('/home/allgoodguys/Documents/Studying/Lund_PhD/epistles/011_soundCol_linguistic/exp1_ipa_brightness/data/ipa_audio.csv')
df = read.csv('data/langs_with_acoustics.csv')
df$L[df$color %in% c('dark', 'night')] = 25
df$L[df$color %in% c('light', 'day')] = 75
# df[, c('sound', 'ampl_median', 'loudness_median')] = ipa[match(df$unicode, ipa$unicode), c('sound', 'ampl_median', 'loudness_median')]
# df[, c('specCentroid', 'peakFreq', 'F1', 'F2', 'F3')] = log(df[, c('specCentroid', 'peakFreq', 'F1', 'F2', 'F3')])
df$L = df$L / 100
df$saturation = df$saturation / 100

dfc = droplevels(df[is.na(df$F1), ])  # only consonants
ipa = droplevels(ipa[is.na(ipa$F1), ])
# cor(ipa[, c('sonority', 'ampl_median', 'loudness_median')])

## predict L from acoustics
cor(dfc[, c('L', 'saturation', 'br', 'specCentroid_median', 'sonority', 'ampl_median', 'loudness_median')], use = 'pairwise.complete.obs')


## specCentroid ~ L
dfc$logSC = log(dfc$specCentroid_median)
# mod_specCentroid_L = brm(logSC ~ L + (1|color) + (L|language), data = dfc, family = 'gaussian', iter = 4000, warmup = 500, chains = 2, cores = 2)
# saveRDS(mod_specCentroid_L, 'models/mod_specCentroid_L.RDS')
mod_specCentroid_L = readRDS('models/mod_specCentroid_L.RDS')
# summary(mod_specCentroid_L)

newdata = data.frame(L = 0:100)
f_specCentroid_L = exp(fitted(mod_specCentroid_L, newdata / 100, re_formula = NA, robust = TRUE))[, c(1, 3:4)]
colnames(f_specCentroid_L) = c('fit', 'lwr', 'upr')
df_plot_specCentroid_L = cbind(newdata, f_specCentroid_L)

a_specCentroid_L = aggregate(logSC ~ color, dfc, mean)
a_specCentroid_L$L = dfc$L[match(a_specCentroid_L$color, dfc$color)] * 100
a_specCentroid_L$specCentroid = exp(a_specCentroid_L$logSC)

f_contrast_specCentroid_L = exp(fitted(mod_specCentroid_L, newdata = data.frame(L = c(0, 1)), re_formula = NA, summary = FALSE))
label_specCentroid_L = paste('\U0394 =' , soundgen:::reportCI(quantile(f_contrast_specCentroid_L[, 2] - f_contrast_specCentroid_L[, 1], probs = c(.5, .025, .975)), digits = 0), 'Hz')
a_specCentroid_L$color = as.character(a_specCentroid_L$color)
a_specCentroid_L$color = paste0(' ', a_specCentroid_L$color, ' ')

p_specCentroid_L = ggplot(df_plot_specCentroid_L, aes(x = L, y = fit, ymin = lwr, ymax = upr)) +
  geom_ribbon(alpha = .25) +
  geom_line() +
  geom_text(data = a_specCentroid_L, aes(x = L, y = specCentroid, label = color), size = 3, inherit.aes = FALSE, hjust = 'inward') +
  geom_point(data = a_specCentroid_L, aes(x = L, y = specCentroid), inherit.aes = FALSE) +
  # scale_x_continuous(breaks = c(0, 25, 50, 75, 100), limits = c(-10, 110)) +
  xlab('Luminance') +
  ylab('Spectral centroid, Hz') +
  ggtitle('B. Spectral centroid', subtitle = label_specCentroid_L) +
  theme_bw() +
  theme(panel.grid = element_blank())


## sonority ~ L
# mod_sonority_L = brm(sonority ~ L + (1|color) + (L|language), data = dfc, family = 'gaussian', iter = 4000, warmup = 500, chains = 2, cores = 2)
# saveRDS(mod_sonority_L, 'models/mod_sonority_L.RDS')
mod_sonority_L = readRDS('models/mod_sonority_L.RDS')
summary(mod_sonority_L)

newdata = data.frame(L = 0:100)
f_sonority_L = fitted(mod_sonority_L, newdata / 100, re_formula = NA, robust = TRUE)[, c(1, 3:4)]
colnames(f_sonority_L) = c('fit', 'lwr', 'upr')
df_plot_sonority_L = cbind(newdata, f_sonority_L)

a_sonority_L = aggregate(sonority ~ color, dfc, mean)
a_sonority_L$L = dfc$L[match(a_sonority_L$color, dfc$color)] * 100

f_contrast_son_L = fitted(mod_sonority_L, newdata = data.frame(L = c(0, 1)), re_formula = NA, summary = FALSE)
label_son_L = paste('\U0394 =' , soundgen:::reportCI(quantile(f_contrast_son_L[, 2] - f_contrast_son_L[, 1], probs = c(.5, .025, .975)), digits = 2))
a_sonority_L$color = as.character(a_sonority_L$color)
a_sonority_L$color = paste0(' ', a_sonority_L$color, ' ')

p_son_L = ggplot(df_plot_sonority_L, aes(x = L, y = fit, ymin = lwr, ymax = upr)) +
  geom_ribbon(alpha = .25) +
  geom_line() +
  geom_text(data = a_sonority_L, aes(x = L, y = sonority, label = color), size = 3, inherit.aes = FALSE, hjust = 'inward') +
  geom_point(data = a_sonority_L, aes(x = L, y = sonority), inherit.aes = FALSE) +
  xlab('Luminance') +
  ylab('Sonority') +
  ggtitle('A. Sonority', subtitle = label_son_L) +
  theme_bw() +
  theme(panel.grid = element_blank())


### SATURATION
# load data
df_sat = droplevels(dfc[!is.na(dfc$saturation), ])   # only consonants, colors with defined saturation
df_sat$logSC = log(df_sat$specCentroid_median)

## predict SAT from acoustics
cor(df_sat[, c('saturation', 'br', 'specCentroid', 'melCentroid')])

## specCentroid ~ SATURATION
# mod_specCentroid_sat = brm(logSC ~ saturation + (1|color) + (saturation|language), data = df_sat, family = 'gaussian', iter = 4000, warmup = 500, chains = 2, cores = 2)
# saveRDS(mod_specCentroid_sat, 'models/mod_specCentroid_sat.RDS')
mod_specCentroid_sat = readRDS('models/mod_specCentroid_sat.RDS')
summary(mod_specCentroid_sat)
# brms::pp_check(mod_specCentroid_sat)

newdata_sat = data.frame(saturation = seq(min(df_sat$saturation), max(df_sat$saturation), length.out = 100))
f_specCentroid_sat = exp(fitted(mod_specCentroid_sat, newdata_sat, re_formula = NA, robust = TRUE))[, c(1, 3:4)]
colnames(f_specCentroid_sat) = c('fit', 'lwr', 'upr')
df_plot_sc_sat = cbind(newdata_sat, f_specCentroid_sat)
df_plot_sc_sat$saturation = df_plot_sc_sat$saturation * 100

a_sc_sat = aggregate(logSC ~ color, df_sat, mean)
a_sc_sat$saturation = df_sat$saturation[match(a_sc_sat$color, df_sat$color)] * 100
a_sc_sat$specCentroid = exp(a_sc_sat$logSC)

f_contrast_sc_sat = exp(fitted(mod_specCentroid_sat, newdata = data.frame(saturation = c(min(df_sat$saturation), max(df_sat$saturation))), re_formula = NA, summary = FALSE))
label_specCentroid_sat = paste('\U0394 =' , soundgen:::reportCI(quantile(f_contrast_sc_sat[, 2] - f_contrast_sc_sat[, 1], probs = c(.5, .025, .975)), digits = 0), 'Hz')
a_sc_sat$color = as.character(a_sc_sat$color)
a_sc_sat$color = paste0(' ', a_sc_sat$color, ' ')

p_specCentroid_sat = ggplot(df_plot_sc_sat, aes(x = saturation, y = fit, ymin = lwr, ymax = upr)) +
  geom_ribbon(alpha = .25) +
  geom_line() +
  geom_text(data = a_sc_sat, aes(x = saturation, y = specCentroid, label = color), size = 3, inherit.aes = FALSE, hjust = 'inward') +
  geom_point(data = a_sc_sat, aes(x = saturation, y = specCentroid), inherit.aes = FALSE) +
  xlab('Saturation') +
  ylab('Spectral centroid, Hz') +
  ggtitle('D. Spectral centroid', subtitle = label_specCentroid_sat) +
  theme_bw() +
  theme(panel.grid = element_blank())


## Sonority ~ saturation
# mod_son_sat = brm(sonority ~ saturation + (1|color) + (saturation|language), data = df_sat, family = 'gaussian', iter = 4000, warmup = 500, chains = 2, cores = 2)
# saveRDS(mod_son_sat, 'models/mod_son_sat.RDS')
mod_son_sat = readRDS('models/mod_son_sat.RDS')
# summary(mod_son_sat)
# brms::pp_check(mod_son_sat)

f_son_sat = fitted(mod_son_sat, newdata_sat, re_formula = NA, robust = TRUE)[, c(1, 3:4)]
colnames(f_son_sat) = c('fit', 'lwr', 'upr')
df_plot_son_sat = cbind(newdata_sat, f_son_sat)
df_plot_son_sat$saturation = df_plot_son_sat$saturation * 100

a_son_sat = aggregate(sonority ~ color, df_sat, mean)
a_son_sat$saturation = df_sat$saturation[match(a_son_sat$color, df_sat$color)] * 100

f_contrast_son_sat = fitted(mod_son_sat, newdata = data.frame(saturation = c(min(df_sat$saturation), max(df_sat$saturation))), re_formula = NA, summary = FALSE)
label_son_sat = paste('\U0394 =' , soundgen:::reportCI(quantile(f_contrast_son_sat[, 2] - f_contrast_son_sat[, 1], probs = c(.5, .025, .975)), digits = 2))
a_son_sat$color = as.character(a_son_sat$color)
a_son_sat$color = paste0(' ', a_son_sat$color, ' ')

p_son_sat = ggplot(df_plot_son_sat, aes(x = saturation, y = fit, ymin = lwr, ymax = upr)) +
  geom_ribbon(alpha = .25) +
  geom_line() +
  geom_text(data = a_son_sat, aes(x = saturation, y = sonority, label = color), size = 3, inherit.aes = FALSE, hjust = 'inward') +
  geom_point(data = a_son_sat, aes(x = saturation, y = sonority), inherit.aes = FALSE) +
  xlab('Saturation') +
  ylab('Sonority') +
  ggtitle('C. Sonority', subtitle = label_son_sat) +
  theme_bw() +
  theme(panel.grid = element_blank())

multiplot(p_son_L, p_son_sat, p_specCentroid_L, p_specCentroid_sat, p_specCentroid_L, p_specCentroid_sat, cols = 3)  # repeat col3 to have the right proportions
ggsave(multiplot(p_son_L, p_son_sat, p_specCentroid_L, p_specCentroid_sat, p_specCentroid_L, p_specCentroid_sat, cols = 3),
       filename = 'pix/consonants.png', width = 20, height = 16, units = 'cm', dpi = 300)

