# Vowels: luminance of color as a predictor of acoustic characteristics of vowels

setwd('/home/allgoodguys/Documents/Studying/Lund_PhD/epistles/011_soundCol_linguistic/exp2_text')

library(ggplot2)
library(lme4)
library(reshape2)
library(brms)
source('/home/allgoodguys/Documents/Soft_comp/R/ggplot_multiple.R')  # from http://www.cookbook-r.com/Graphs/Multiple_graphs_on_one_page_(ggplot2)/

# load data
ipa = read.csv('data/ipa_audio.csv')
# lab = read.csv('data/colors_lab.csv')
# lab = read.csv('data/colors_lab_munsel.csv')
df = read.csv('data/langs_with_acoustics.csv')

# # Add variables
# v_ipa = c('ampl_median', 'loudness_median', 'sonority', 'sonority_group')
# df[, v_ipa] = ipa[match(df$unicode, ipa$unicode), v_ipa]
# v_lab = c('L', 'a', 'b', 'saturation', 'warmth')
# df[, v_lab] = lab[match(df$color, lab$color), v_lab]
# write.csv(df, 'data/langs_with_acoustics.csv')

df$L[df$color %in% c('dark', 'night')] = 25
df$L[df$color %in% c('light', 'day')] = 75
# df[, c('specCentroid', 'F1', 'F2')] = log(df[, c('specCentroid', 'F1', 'F2')])
df$L = df$L / 100
df$br = df$br / 100

df = droplevels(df[!is.na(df$F1), ])  # only vowels
ipa = droplevels(ipa[!is.na(ipa$F1), ])

# ## predict L from acoustics
# cor(ipa[, c('br', 'sonority', 'F1', 'F2', 'F3', 'ampl_median', 'loudness_median')])
# cor(df[, c('L', 'br', 'brs', 'specCentroid_median', 'F1', 'F2', 'F3', 'sonority', 'ampl_median', 'loudness_median')])[, 1]
# summary(lm(L ~ br + specCentroid_median + F1 + F2 + F3, data = df))  # only br
# summary(lm(L ~ sonority + br, data = df))  # both
# summary(lm(L ~ sonority + br + F1, data = df)) # except F1
# summary(lm(L ~ sonority + F1, data = df))  # only sonority
# summary(lm(L ~ br + F1, data = df))  # both

## SONORITY
# head(df[, c('language', 'unicode', 'sonority', 'color', 'L')])
# mod_sonority = brm(sonority ~ L + (1|color) + (L|language), data = df, family = 'gaussian', iter = 4000, warmup = 500, chains = 2, cores = 2)
# saveRDS(mod_sonority, 'models/mod_sonority.RDS')
mod_sonority = readRDS('models/mod_sonority.RDS')
# summary(mod_sonority)
# brms::pp_check(mod_sonority)

newdata = data.frame(L = 0:100)
f_sonority = fitted(mod_sonority, newdata / 100, re_formula = NA, robust = TRUE)[, c(1, 3:4)]
colnames(f_sonority) = c('fit', 'lwr', 'upr')
df_plot_sonority = cbind(newdata, f_sonority)

a_sonority = aggregate(sonority ~ color, df, mean)
a_sonority$L = df$L[match(a_sonority$color, df$color)] * 100

f_sonority_contrast = fitted(mod_sonority, newdata = data.frame(L = c(0, 1)), re_formula = NA, summary = FALSE)
label_sonority = paste('\U0394 =' , soundgen:::reportCI(quantile(f_sonority_contrast[, 2] - f_sonority_contrast[, 1], probs = c(.5, .025, .975)), digits = 1))

a_sonority$color = as.character(a_sonority$color)
a_sonority$color = paste0(' ', a_sonority$color, ' ')
p_sonority = ggplot(df_plot_sonority, aes(x = L, y = fit, ymin = lwr, ymax = upr)) +
  geom_ribbon(alpha = .25) +
  geom_line() +
  geom_text(data = a_sonority, aes(x = L, y = sonority, label = color), size = 3, inherit.aes = FALSE, hjust = 'inward') +
  geom_point(data = a_sonority, aes(x = L, y = sonority), inherit.aes = FALSE) +
  xlab('Luminance (L)') +
  ylab('Sonority') +
  scale_x_continuous(breaks = c(0, 25, 50, 75, 100), limits = c(0, 102)) +
  ggtitle('A. Sonority', subtitle = label_sonority) +
  theme_bw() +
  theme(panel.grid = element_blank()) +
  geom_segment(x = 0, y = df_plot_sonority$fit[1], xend = 100, yend = df_plot_sonority$fit[1], linetype = 2, size = .1) +
  geom_segment(x = 100, y = tail(df_plot_sonority$fit, 1), xend = 100, yend = tail(df_plot_sonority$fit, 1), linetype = 2, size = .1) +
  geom_segment(x = 100, y = df_plot_sonority$fit[1], xend = 100, yend = tail(df_plot_sonority$fit, 1), linetype = 1, size = .1, arrow = arrow(angle = 15, ends = 'both', length = unit(.05, "npc"))) +
  annotate('text', x = 97, y = mean(c(df_plot_sonority$fit[1], tail(df_plot_sonority$fit, 1))), label = "\U0394", size = 3)

# F1
df$logF1 = log(df$F1)
# mod_f1 = brm(logF1 ~ L + (1|color) + (L|language), data = df, family = 'gaussian', iter = 4000, warmup = 500, chains = 2, cores = 2)
# saveRDS(mod_f1, 'models/mod_f1.RDS')
mod_f1 = readRDS('models/mod_f1.RDS')
# summary(mod_f1)

f_f1 = exp(fitted(mod_f1, newdata / 100, re_formula = NA, robust = TRUE))[, c(1, 3:4)]
colnames(f_f1) = c('fit', 'lwr', 'upr')
df_plot_f1 = cbind(newdata, f_f1)

a_f1 = aggregate(logF1 ~ color, df, mean)
a_f1$L = df$L[match(a_f1$color, df$color)] * 100
a_f1$F1 = exp(a_f1$logF1)

f_f1_contrast = exp(fitted(mod_f1, newdata = data.frame(L = c(0, 1)), re_formula = NA, summary = FALSE))
label_f1 = paste('\U0394 =' , soundgen:::reportCI(quantile(f_f1_contrast[, 2] - f_f1_contrast[, 1], probs = c(.5, .025, .975)), digits = 0), 'Hz')
a_f1$color = as.character(a_f1$color)
a_f1$color = paste0(' ', a_f1$color, ' ')

p_f1 = ggplot(df_plot_f1, aes(x = L, y = fit, ymin = lwr, ymax = upr)) +
  geom_ribbon(alpha = .25) +
  geom_line() +
  geom_text(data = a_f1, aes(x = L, y = F1, label = color), size = 3, inherit.aes = FALSE, hjust = 'inward') +
  geom_point(data = a_f1, aes(x = L, y = F1), inherit.aes = FALSE) +
  xlab('Luminance (L)') +
  ylab('F1, Hz') +
  ggtitle('D. First formant', subtitle = label_f1) +
  theme_bw() +
  theme(panel.grid = element_blank())


# F2
df$logF2 = log(df$F2)
# mod_f2 = brm(logF2 ~ L + (1|color) + (L|language), data = df, family = 'gaussian', iter = 4000, warmup = 500, chains = 2, cores = 2)
# saveRDS(mod_f2, 'models/mod_f2.RDS')
mod_f2 = readRDS('models/mod_f2.RDS')
# summary(mod_f2)

f_f2 = exp(fitted(mod_f2, newdata / 100, re_formula = NA, robust = TRUE))[, c(1, 3:4)]
colnames(f_f2) = c('fit', 'lwr', 'upr')
df_plot_f2 = cbind(newdata, f_f2)

a_f2 = aggregate(logF2 ~ color, df, mean)
a_f2$L = df$L[match(a_f2$color, df$color)] * 100
a_f2$F2 = exp(a_f2$logF2)

f_f2_contrast = exp(fitted(mod_f2, newdata = data.frame(L = c(0, 1)), re_formula = NA, summary = FALSE))
label_f2 = paste('\U0394 =' , soundgen:::reportCI(quantile(f_f2_contrast[, 2] - f_f2_contrast[, 1], probs = c(.5, .025, .975)), digits = 0), 'Hz')
a_f2$color = as.character(a_f2$color)
a_f2$color = paste0(' ', a_f2$color, ' ')

p_f2 = ggplot(df_plot_f2, aes(x = L, y = fit, ymin = lwr, ymax = upr)) +
  geom_ribbon(alpha = .25) +
  geom_line() +
  geom_text(data = a_f2, aes(x = L, y = F2, label = color), size = 3, inherit.aes = FALSE, hjust = 'inward') +
  geom_point(data = a_f2, aes(x = L, y = F2), inherit.aes = FALSE) +
  xlab('Luminance (L)') +
  ylab('F2, Hz') +
  ggtitle('E. Second formant', subtitle = label_f2) +
  theme_bw() +
  theme(panel.grid = element_blank())


## F3
df$logF3 = log(df$F3)
# mod_f3 = brm(logF3 ~ L + (1|color) + (L|language), data = df, family = 'gaussian', iter = 4000, warmup = 500, chains = 2, cores = 2)
# saveRDS(mod_f3, 'models/mod_f3.RDS')
mod_f3 = readRDS('models/mod_f3.RDS')
# summary(mod_f3)

f_f3 = exp(fitted(mod_f3, newdata / 100, re_formula = NA, robust = TRUE))[, c(1, 3:4)]
colnames(f_f3) = c('fit', 'lwr', 'upr')
df_plot_f3 = cbind(newdata, f_f3)

a_f3 = aggregate(logF3 ~ color, df, mean)
a_f3$L = df$L[match(a_f3$color, df$color)] * 100
a_f3$F3 = exp(a_f3$logF3)

f_f3_contrast = exp(fitted(mod_f3, newdata = data.frame(L = c(0, 1)), re_formula = NA, summary = FALSE))
label_f3 = paste('\U0394 =' , soundgen:::reportCI(quantile(f_f3_contrast[, 2] - f_f3_contrast[, 1], probs = c(.5, .025, .975)), digits = 0), 'Hz')
a_f3$color = as.character(a_f3$color)
a_f3$color = paste0(' ', a_f3$color, ' ')

p_f3 = ggplot(df_plot_f3, aes(x = L, y = fit, ymin = lwr, ymax = upr)) +
  geom_ribbon(alpha = .25) +
  geom_line() +
  geom_text(data = a_f3, aes(x = L, y = F3, label = color), size = 3, inherit.aes = FALSE, hjust = 'inward') +
  geom_point(data = a_f3, aes(x = L, y = F3), inherit.aes = FALSE) +
  xlab('Luminance (L)') +
  ylab('F3, Hz') +
  ggtitle('F. Third formant', subtitle = label_f3) +
  theme_bw() +
  theme(panel.grid = element_blank())


## BRIGHTNESS
# # simple model selection
# library(lme4)
# mod1 = glm(br ~ L, data = df)
# mod2 = lmer(br ~ L + (1|color), data = df)
# mod3 = lmer(br ~ L + (1|color) + (1|language), data = df)
# mod4 = lmer(br ~ L + (1|color) + (L|language), data = df)
# AIC(mod1, mod2, mod3, mod4)  # mod4
# anova(mod2, mod3, mod4)

# df$br01 = df$br / 102 + .01  # range(df$br01)
# mod_br = brm(br ~ L + (1|color) + (L|language), data = df, family = 'gaussian', iter = 4000, warmup = 500, chains = 2, cores = 2)  # slightly weird fit with beta instead of gaussian
# saveRDS(mod_br, 'models/mod_br.RDS')
mod_br = readRDS('models/mod_br.RDS')
summary(mod_br)

f_br = fitted(mod_br, newdata / 100, re_formula = NA, robust = TRUE)[, c(1, 3:4)]
colnames(f_br) = c('fit', 'lwr', 'upr')
df_plot_br = cbind(newdata, f_br)
df_plot_br[, c('fit', 'lwr', 'upr')] = df_plot_br[, c('fit', 'lwr', 'upr')] * 100

a_br = aggregate(br ~ color, df, function(x) mean(x) * 100)
a_br$L = df$L[match(a_br$color, df$color)] * 100

f_br_contrast = fitted(mod_br, newdata = data.frame(L = c(0, 1)), re_formula = NA, summary = FALSE)
label_br = paste0('\U0394 = ' , soundgen:::reportCI(quantile(f_br_contrast[, 2] - f_br_contrast[, 1], probs = c(.5, .025, .975)) * 100, digits = 0), ' %')
a_br$color = as.character(a_br$color)
a_br$color = paste0(' ', a_br$color, ' ')

p_br = ggplot(df_plot_br, aes(x = L, y = fit, ymin = lwr, ymax = upr)) +
  geom_ribbon(alpha = .25) +
  geom_line() +
  geom_text(data = a_br, aes(x = L, y = br, label = color), size = 3, inherit.aes = FALSE, hjust = 'inward') +
  geom_point(data = a_br, aes(x = L, y = br), inherit.aes = FALSE) +
  xlab('Luminance (L)') +
  ylab('Brightness, %') +
  ggtitle('B. Brightness ratings', subtitle = label_br) +
  theme_bw() +
  theme(panel.grid = element_blank())


## SPECTRAL CENTROID
df$logSC = log(df$specCentroid_median)
# mod_specCentroid = brm(logSC ~ L + (1|color) + (L|language), data = df, family = 'gaussian', iter = 4000, warmup = 500, chains = 2, cores = 2)
# saveRDS(mod_specCentroid, 'models/mod_specCentroid.RDS')
mod_specCentroid = readRDS('models/mod_specCentroid.RDS')
# summary(mod_specCentroid)
# brms::pp_check(mod_specCentroid)

f_specCentroid = exp(fitted(mod_specCentroid, newdata / 100, re_formula = NA, robust = TRUE))[, c(1, 3:4)]
colnames(f_specCentroid) = c('fit', 'lwr', 'upr')
df_plot_specCentroid = cbind(newdata, f_specCentroid)

a_specCentroid = aggregate(logSC ~ color, df, mean)
a_specCentroid$L = df$L[match(a_specCentroid$color, df$color)] * 100
a_specCentroid$specCentroid = exp(a_specCentroid$logSC)

f_specCentroid_contrast = exp(fitted(mod_specCentroid, newdata = data.frame(L = c(0, 1)), re_formula = NA, summary = FALSE))
label_specCentroid = paste('\U0394 =' , soundgen:::reportCI(quantile(f_specCentroid_contrast[, 2] - f_specCentroid_contrast[, 1], probs = c(.5, .025, .975)), digits = 0), 'Hz')
a_specCentroid$color = as.character(a_specCentroid$color)
a_specCentroid$color = paste0(' ', a_specCentroid$color, ' ')

p_specCentroid = ggplot(df_plot_specCentroid, aes(x = L, y = fit, ymin = lwr, ymax = upr)) +
  geom_ribbon(alpha = .25) +
  geom_line() +
  geom_text(data = a_specCentroid, aes(x = L, y = specCentroid, label = color), size = 3, inherit.aes = FALSE, hjust = 'inward') +
  geom_point(data = a_specCentroid, aes(x = L, y = specCentroid), inherit.aes = FALSE) +
  xlab('Luminance (L)') +
  ylab('Spectral centroid, Hz') +
  ggtitle('C. Spectral centroid', subtitle = label_specCentroid) +
  theme_bw() +
  theme(panel.grid = element_blank())


multiplot(p_sonority, p_f1, p_br, p_f2, p_specCentroid, p_f3, cols = 3)
ggsave(multiplot(p_sonority, p_f1, p_br, p_f2, p_specCentroid, p_f3, cols = 3),
       filename = 'pix/vowels.png', width = 20, height = 16, units = 'cm', dpi = 300)




# Check which colors are "outliers" in terms of how much they deviate from the general trend
# accounted for by luminance (look at random intercept per color in each model)
m = as.data.frame(mod_f2$fit)  # mod_sonority, mod_br, mod_specCentroid, mod_f1, mod_f2, mod_f3
m = m[, grep(pattern = 'r_color', x = names(m))]
colnames(m) = levels(df$color)
col_resid = data.frame(color = colnames(m))
col_resid[, c('fit', 'lwr', 'upr')] = t(apply(m, 2, function(x) quantile(x, probs = c(.5, .025, .975))))
col_resid$formatted = soundgen:::reportCI(col_resid[, c('fit', 'lwr', 'upr')], 3) 
# for brightness: col_resid$formatted = soundgen:::reportCI(col_resid[, c('fit', 'lwr', 'upr')] * 100, 3) 
col_resid
# For sonority, only dark: -0.1 [-0.21, -0.01]
# For brightness, green 3.6 [0.8, 6.9], marginal dark -2.9 [-6.7, 0.4], gray -3.1 [-7.2, 0.2], red 2.5 [-0.4, 5.9]
# For specCentroid, gray -5.2 [-10.8, -0.7] and green 4.4 [0.7, 8.6]
# Nothing clear for f1 and f3
# For f2, gray -5.2 [-11.2, -0.4], marginal green 3.7 [-0.2, 8.1] and red 3.5 [-0.5, 8.5] 


######
# ## RMS AMPLITUDE
# # mod_ampl = brm(ampl_median ~ L + (1|color) + (L|language), data = df, family = 'gaussian', iter = 4000, warmup = 500, chains = 2, cores = 2)
# # saveRDS(mod_ampl, 'models/mod_ampl.RDS')
# mod_ampl = readRDS('models/mod_ampl.RDS')
# # summary(mod_ampl)
# # brms::pp_check(mod_ampl)
#
# f_ampl = fitted(mod_ampl, newdata / 100, re_formula = NA, robust = TRUE)[, c(1, 3:4)]
# colnames(f_ampl) = c('fit', 'lwr', 'upr')
# df_plot_ampl = cbind(newdata, f_ampl)
#
# a_ampl = aggregate(ampl_median ~ color, df, mean)
# a_ampl$L = df$L[match(a_ampl$color, df$color)] * 100
#
# f_ampl_contrast = fitted(mod_ampl, newdata = data.frame(L = c(0, 1)), re_formula = NA, summary = FALSE)
# label_ampl = paste('\U0394 =' , soundgen:::reportCI(quantile(f_ampl_contrast[, 2] - f_ampl_contrast[, 1], probs = c(.5, .025, .975)), digits = 3))
# a_ampl$color = as.character(a_ampl$color)
# a_ampl$color = paste0(' ', a_ampl$color, ' ')
#
# p_ampl = ggplot(df_plot_ampl, aes(x = L, y = fit, ymin = lwr, ymax = upr)) +
#   geom_ribbon(alpha = .25) +
#   geom_line() +
#   geom_text(data = a_ampl, aes(x = L, y = ampl_median, label = color), size = 3, inherit.aes = FALSE, hjust = 'inward') +
#   geom_point(data = a_ampl, aes(x = L, y = ampl_median), inherit.aes = FALSE) +
#   xlab('Luminance (L)') +
#   ylab('RMS amplitude') +
#   ggtitle('B. RMS amplitude', subtitle = label_ampl) +
#   theme_bw() +
#   theme(panel.grid = element_blank())
#
#
# ## LOUDNESS
# # mod_loud = brm(loudness_median ~ L + (1|color) + (L|language), data = df, family = 'gaussian', iter = 4000, warmup = 500, chains = 2, cores = 2)
# # saveRDS(mod_loud, 'models/mod_loud.RDS')
# mod_loud = readRDS('models/mod_loud.RDS')
# # summary(mod_loud)
# # brms::pp_check(mod_loud)
#
# f_loud = fitted(mod_loud, newdata / 100, re_formula = NA, robust = TRUE)[, c(1, 3:4)]
# colnames(f_loud) = c('fit', 'lwr', 'upr')
# df_plot_loud = cbind(newdata, f_loud)
#
# a_loud = aggregate(loudness_median ~ color, df, mean)
# a_loud$L = df$L[match(a_loud$color, df$color)] * 100
#
# f_loud_contrast = fitted(mod_loud, newdata = data.frame(L = c(0, 1)), re_formula = NA, summary = FALSE)
# label_loud = paste('\U0394 =' , soundgen:::reportCI(quantile(f_loud_contrast[, 2] - f_loud_contrast[, 1], probs = c(.5, .025, .975)), digits = 1), 'sone')
# a_loud$color = as.character(a_loud$color)
# a_loud$color = paste0(' ', a_loud$color, ' ')
#
# p_loud = ggplot(df_plot_loud, aes(x = L, y = fit, ymin = lwr, ymax = upr)) +
#   geom_ribbon(alpha = .25) +
#   geom_line() +
#   geom_text(data = a_loud, aes(x = L, y = loudness_median, label = color), size = 3, inherit.aes = FALSE, hjust = 'inward') +
#   geom_point(data = a_loud, aes(x = L, y = loudness_median), inherit.aes = FALSE) +
#   xlab('Luminance (L)') +
#   ylab('Loudness, sone') +
#   ggtitle('C. Loudness', subtitle = label_loud) +
#   theme_bw() +
#   theme(panel.grid = element_blank())
