# Vowels: saturation of color as a predictor of acoustic characteristics of vowels

setwd('/home/allgoodguys/Documents/Studying/Lund_PhD/epistles/011_soundCol_linguistic/exp2_text')

library(ggplot2)
library(lme4)
library(reshape2)
library(brms)
source('/home/allgoodguys/Documents/Soft_comp/R/ggplot_multiple.R')  # from http://www.cookbook-r.com/Graphs/Multiple_graphs_on_one_page_(ggplot2)/

# load data
df = read.csv('data/langs_with_acoustics.csv')
df = droplevels(df[!is.na(df$F1), ])  # only vowels

df$saturation = df$saturation / 100
df$br = df$br / 100

df_sat = df[!is.na(df$saturation), ]   # only vowels, colors with defined saturation
df_sat$logSC = log(df_sat$specCentroid_median)

# cor(df_sat[, c('saturation', 'sonority', 'br', 'brs', 'specCentroid_median', 'F1', 'F2', 'F3')])[, 1]


## sonority
# mod_sonority_sat_v = brm(sonority ~ saturation + (1|color) + (saturation|language), data = df_sat, family = 'gaussian', iter = 4000, warmup = 500, chains = 2, cores = 2)
# saveRDS(mod_sonority_sat_v, 'models/mod_sonority_sat_v.RDS')
mod_sonority_sat_v = readRDS('models/mod_sonority_sat_v.RDS')
# summary(mod_sonority_sat_v)
# brms::pp_check(mod_sonority_sat_v)

newdata = data.frame(saturation = seq(min(df_sat$saturation), max(df_sat$saturation), length.out = 100))
f_sonority_sat = fitted(mod_sonority_sat_v, newdata, re_formula = NA, robust = TRUE)[, c(1, 3:4)]
colnames(f_sonority_sat) = c('fit', 'lwr', 'upr')
df_plot_sonority_sat = cbind(newdata, f_sonority_sat)
df_plot_sonority_sat$saturation = df_plot_sonority_sat$saturation * 100

a_sonority_sat = aggregate(sonority ~ color, df_sat, mean)
a_sonority_sat$saturation = df_sat$saturation[match(a_sonority_sat$color, df_sat$color)] * 100

f_contrast_sonority_sat = fitted(mod_sonority_sat_v, newdata = data.frame(saturation = c(min(df_sat$saturation), max(df_sat$saturation))), re_formula = NA, summary = FALSE)
label_sonority_sat = paste('\U0394 =' , soundgen:::reportCI(quantile(f_contrast_sonority_sat[, 2] - f_contrast_sonority_sat[, 1], probs = c(.5, .025, .975)), digits = 2))
a_sonority_sat$color = as.character(a_sonority_sat$color)
a_sonority_sat$color = paste0(' ', a_sonority_sat$color, ' ')

p_sonority_sat = ggplot(df_plot_sonority_sat, aes(x = saturation, y = fit, ymin = lwr, ymax = upr)) +
  geom_ribbon(alpha = .25) +
  geom_line() +
  geom_text(data = a_sonority_sat, aes(x = saturation, y = sonority, label = color), size = 3, inherit.aes = FALSE, hjust = 'inward') +
  geom_point(data = a_sonority_sat, aes(x = saturation, y = sonority), inherit.aes = FALSE) +
  # scale_x_continuous(breaks = c(0, 25, 50, 75, 100, 125), limits = c(-10, 140)) +
  xlab('Saturation') +
  ylab('Sonority') +
  ggtitle('A. Sonority', subtitle = label_sonority_sat) +
  theme_bw() +
  theme(panel.grid = element_blank())

# alternative plot, with centered labels and expanded x axis
r_son_sat = diff(range(a_sonority_sat$sonority, na.rm = T))
p_sonority_sat = ggplot(df_plot_sonority_sat, aes(x = saturation, y = fit, ymin = lwr, ymax = upr)) +
  geom_ribbon(alpha = .25) +
  geom_line() +
  geom_text(data = a_sonority_sat, aes(x = saturation, y = sonority, label = color), size = 3, inherit.aes = FALSE, hjust = 'center', nudge_y = -.05 * r_son_sat) +
  geom_point(data = a_sonority_sat, aes(x = saturation, y = sonority), inherit.aes = FALSE) +
  scale_x_continuous(limits = c(-10, max(df_plot_sonority_sat$saturation) + 10)) +
  xlab('Saturation') +
  ylab('Sonority') +
  ggtitle('A. Sonority', subtitle = label_sonority_sat) +
  theme_bw() +
  theme(panel.grid = element_blank())


## br ~ saturation
# df_sat$br01 = df_sat$br / 102 + .01  # range(df_sat$br01)
# mod_br_sat_v = brm(br ~ saturation  + (1|color) + (saturation|language), data = df_sat, family = 'gaussian', iter = 4000, warmup = 500, chains = 2, cores = 2)
# saveRDS(mod_br_sat_v, 'models/mod_br_sat_v.RDS')
mod_br_sat_v = readRDS('models/mod_br_sat_v.RDS')
summary(mod_br_sat_v)

f_br_sat = fitted(mod_br_sat_v, newdata, re_formula = NA, robust = TRUE)[, c(1, 3:4)]
colnames(f_br_sat) = c('fit', 'lwr', 'upr')
df_plot_br_sat = cbind(newdata, f_br_sat)
df_plot_br_sat[, c('saturation', 'fit', 'lwr', 'upr')] = df_plot_br_sat[, c('saturation', 'fit', 'lwr', 'upr')] * 100

a_br_sat = aggregate(br ~ color, df_sat, function(x) mean(x) * 100)
a_br_sat$saturation = df_sat$saturation[match(a_br_sat$color, df_sat$color)] * 100

f_br_contrast = fitted(mod_br_sat_v, newdata = data.frame(saturation = c(min(df_sat$saturation), max(df_sat$saturation))), re_formula = NA, summary = FALSE)
label_br_sat = paste0('\U0394 = ' , soundgen:::reportCI(quantile(f_br_contrast[, 2] - f_br_contrast[, 1], probs = c(.5, .025, .975)) * 100, digits = 0), ' %')
a_br_sat$color = as.character(a_br_sat$color)
a_br_sat$color = paste0(' ', a_br_sat$color, ' ')

p_br_sat = ggplot(df_plot_br_sat, aes(x = saturation, y = fit, ymin = lwr, ymax = upr)) +
  geom_ribbon(alpha = .25) +
  geom_line() +
  geom_text(data = a_br_sat, aes(x = saturation, y = br, label = color), size = 3, inherit.aes = FALSE, hjust = 'inward') +
  geom_point(data = a_br_sat, aes(x = saturation, y = br), inherit.aes = FALSE) +
  xlab('Saturation') +
  ylab('Brightness, %') +
  ggtitle('B. Brightness ratings', subtitle = label_br_sat) +
  theme_bw() +
  theme(panel.grid = element_blank())


## specCentroid
# mod_specCentroid_sat_v = brm(logSC ~ saturation + (1|color) + (saturation|language), data = df_sat, family = 'gaussian', iter = 4000, warmup = 500, chains = 2, cores = 2)
# saveRDS(mod_specCentroid_sat_v, 'models/mod_specCentroid_sat_v.RDS')
mod_specCentroid_sat_v = readRDS('models/mod_specCentroid_sat_v.RDS')
# summary(mod_specCentroid_sat_v)
# brms::pp_check(mod_specCentroid_sat_v)

f_specCentroid_sat = exp(fitted(mod_specCentroid_sat_v, newdata, re_formula = NA, robust = TRUE))[, c(1, 3:4)]
colnames(f_specCentroid_sat) = c('fit', 'lwr', 'upr')
df_plot_specCentroid_sat = cbind(newdata, f_specCentroid_sat)
df_plot_specCentroid_sat$saturation = df_plot_specCentroid_sat$saturation * 100

a_specCentroid_sat = aggregate(logSC ~ color, df_sat, mean)
a_specCentroid_sat$saturation = df_sat$saturation[match(a_specCentroid_sat$color, df_sat$color)]
a_specCentroid_sat$specCentroid = exp(a_specCentroid_sat$logSC)
a_specCentroid_sat$saturation = a_specCentroid_sat$saturation * 100

f_contrast_specCentroid_sat = exp(fitted(mod_specCentroid_sat_v, newdata = data.frame(saturation = c(min(df_sat$saturation), max(df_sat$saturation))), re_formula = NA, summary = FALSE))
label_specCentroid_sat = paste('\U0394 =' , soundgen:::reportCI(quantile(f_contrast_specCentroid_sat[, 2] - f_contrast_specCentroid_sat[, 1], probs = c(.5, .025, .975)), digits = 0), 'Hz')
a_specCentroid_sat$color = as.character(a_specCentroid_sat$color)
a_specCentroid_sat$color = paste0(' ', a_specCentroid_sat$color, ' ')

p_specCentroid_sat = ggplot(df_plot_specCentroid_sat, aes(x = saturation, y = fit, ymin = lwr, ymax = upr)) +
  geom_ribbon(alpha = .25) +
  geom_line() +
  geom_text(data = a_specCentroid_sat, aes(x = saturation, y = specCentroid, label = color), size = 3, inherit.aes = FALSE, hjust = 'inward') +
  geom_point(data = a_specCentroid_sat, aes(x = saturation, y = specCentroid), inherit.aes = FALSE) +
  xlab('Saturation') +
  ylab('Spectral centroid, Hz') +
  ggtitle('C. Spectral centroid', subtitle = label_specCentroid_sat) +
  theme_bw() +
  theme(panel.grid = element_blank())


multiplot(p_sonority_sat, p_br_sat, p_specCentroid_sat, cols = 3)
ggsave(multiplot(p_sonority_sat, p_br_sat, p_specCentroid_sat, cols = 3),
       filename = 'pix/vowels_sat.png', width = 20, height = 8, units = 'cm', dpi = 300)
